==> speech-analytic-testing_6.0.2_database.tar.gz: database/mssql/procedures/GetNluIntentUtteranceToExport.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetNluIntentUtteranceToExport]
(
	@VCC	VARCHAR(50),
	@ListMode INT = 0,
    @UseRasaApi BIT = null
)
AS
BEGIN
	SET NOCOUNT ON
    --@ListMode = 0 resumen de nlus a exportar VCC A VCC solo los que no son de sistema
    --@ListMode = 1 listado de nlus a exportar VCC A VCC solo los que no son de sistema
    --@ListMode = 2 resumen de nlus a exportar RASA A RASAAPI O VICEVERSA todos los nlu de todo el sistema
    --@ListMode = 3 listado de nlus a exportar RASA A RASAAPI O VICEVERSA todos los nlu de todo el sistema
	
	DECLARE @NLU TABLE(
	 [Name] VARCHAR(50),
	 AppId VARCHAR(50)
	)
	DECLARE @Intent TABLE (
	ID VARCHAR(50)
	)

    IF (@ListMode = 0 OR @ListMode = 1)
    BEGIN
        INSERT INTO @NLU SELECT [Name],[AppId] FROM [NLU]  (NOLOCK) WHERE [VCC] = @VCC AND [IsSystemApp] = 0 AND [Status] <> 4
        INSERT INTO @Intent SELECT [IntentId] FROM [Intent] (NOLOCK) WHERE [VCC] = @VCC AND [AppId] IN (SELECT [AppId] FROM @NLU)
    END
    ELSE
    BEGIN
        INSERT INTO @NLU SELECT  [Name],[AppId] FROM [NLU]  (NOLOCK) WHERE [VCC] = @VCC  AND [Status] <> 4
    END
   

	IF(@ListMode = 0) -- CONTAR TOTAL DE REGISTROS
	   BEGIN

        DECLARE @TotalNlu INT = 0
        DECLARE @TotalIntent INT = 0
        DECLARE @TotalUtterance INT = 0
        DECLARE @TotalEntity INT = 0
        DECLARE @NluNames VARCHAR(MAX) = NULL
                
        SELECT @TotalNlu = COUNT([Name]) FROM [NLU] (NOLOCK) WHERE [VCC] = @VCC AND [Name] IN (SELECT [Name] FROM @NLU)

        SELECT @TotalIntent = COUNT([IntentId]) FROM [Intent] (NOLOCK) WHERE [VCC] = @VCC AND [IntentId] IN (SELECT ID FROM @Intent)

        SELECT @TotalUtterance = COUNT([Id]) FROM [Utterance] (NOLOCK) WHERE [VCC] = @VCC AND [IntentId] IN (SELECT ID FROM @Intent)
                
        SELECT @TotalEntity = COUNT([ID]) FROM [dbo].[Entity] WHERE [VCC] = @VCC AND [AppId] IN (SELECT [AppId] FROM @NLU)

        SELECT @TotalNlu AS TotalNlu,@TotalIntent AS TotalIntent,@TotalUtterance AS TotalUtterance, @TotalEntity AS TotalEntity
                
        SELECT @NluNames = STUFF(( SELECT ',' + [Name] FROM [NLU]  WHERE [VCC] = @VCC AND [IsSystemApp] = 0 FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')
            
       
		SELECT 0 'InUse'
          --EXEC [GetNlusUsage] @VCC,@NluNames

	   END
	   IF (@ListMode = 1)
	   BEGIN
	   --NLUS
	       SELECT 
	       [Name]                name,
	       [Name]                originalName,
	       [Culture]             culture, 
	       [Description]         description,
	       [AppId]               appId,
	       [CognitiveEngine]     cognitiveEngine,
	       0                     'status',
	       0                    'totalRetries'
	       FROM [NLU] (NOLOCK) WHERE [VCC] = @VCC AND [Name] IN (SELECT [Name] FROM @NLU)
					--INTENTS
					   SELECT
			[Name]     'name',
			[IntentId] 'intentId',
			[AppId]     'appId',
			CONCAT([AppId],'[::]',[IntentId]) 'key',
			0                     'status',
	        0                    'totalRetries'
			FROM [Intent] (NOLOCK) WHERE [VCC] = @VCC AND [IntentId] IN (SELECT ID FROM @Intent)
					--UTTERANCES  
					  
			 SELECT DISTINCT
			 U.[Id] 'id',
			 U.[AppId]       'appId',
			 I.[Name]    'intent',
			 U.[IntentId] 'intentId',
			 U.[Text] 'name',
			 (SELECT [EntityName] 'entityName',[Start] 'start',[End] 'end' 
			 FROM [UtteranceEntity] (NOLOCK) WHERE [VCC] = @VCC AND [UtteranceId] IN(U.[Id]) FOR JSON AUTO) 'rawEntityLabels',
			 CONCAT(U.[AppId],'[::]',U.[IntentId],'[::]',U.[Id]) 'key',
			 CONCAT(U.[AppId],'[::]',I.[IntentId]) 'intentKey',
			 0                     'status',
			 0                    'totalRetries'
			 
			 FROM [Utterance] U (NOLOCK) 
			 JOIN [Intent] I (NOLOCK)
			 ON (U.VCC = I.VCC AND U.IntentId = I.IntentId)
			 WHERE U.[VCC] = @VCC AND U.[IntentId] IN (SELECT ID FROM @Intent)
			 
			  --ENTITIES
			 SELECT 
			 [AppId] 'appId',
			 [ID] 'id',
			 [Name] 'name',
			 CONCAT([AppId],'[::]',[ID]) 'key',
			  0                     'status',
			 0                    'totalRetries'
			 FROM [dbo].[Entity] WHERE [VCC] = @VCC AND [AppId] IN (SELECT [AppId] FROM @NLU)
	   END
       IF (@ListMode = 2)
       BEGIN
        IF(@VCC ='ALL') --LISTAR RESUMEN PARA TODOS LOS VCCS RASA O RASAAPI
        BEGIN
                WITH ALL_NLUS AS (
                    SELECT   N.[VCC],N.[CognitiveEngine],
                    (SELECT COUNT(1) FROM [dbo].[Nlu] WHERE VCC = N.[VCC] AND appid = N.appid) 'totalNlu',
					0 'totalIntent',
                    0 'totalUtterance',
                    0 'totalEntity'


                    FROM [dbo].[Nlu] N WHERE 
                    N.[CognitiveEngine] = IIF(@UseRasaApi = 1,'RASA','RASAAPI')
                )

                SELECT TOP 1 
                    AN.[VCC]                'vcc',
                    AN.[CognitiveEngine]    'cognitiveEngine',
                    SUM(TotalNlu)               'totalNlu',
                    SUM(TotalIntent)            'totalIntent',
                    SUM(TotalUtterance)         'totalUtterance',
                    SUM(TotalEntity)            'totalEntity'
                FROM ALL_NLUS AN
                    INNER JOIN [dbo].[VCC] V ON V.[VCC] = AN.[VCC]
                WHERE V.[IsMigrating] = 0 
                    GROUP BY AN.[VCC],  AN.[CognitiveEngine]	
            		
        END
        SELECT 0 'InUse'
      END
     IF (@ListMode = 3)
	   BEGIN
	   --NLUS
	       SELECT 
	       [Name]                name,
	       [Name]                originalName,
	       [Culture]             culture, 
	       [Description]         description,
	       [AppId]               appId,
	       [CognitiveEngine]     cognitiveEngine,
	       0                     'status',
	       0                    'totalRetries'
	       FROM [NLU] (NOLOCK) WHERE [VCC] = @VCC AND [Name] IN (SELECT [Name] FROM @NLU)
		 --INTENTS
					   SELECT
			[Name]     'name',
			[IntentId] 'intentId',
			[AppId]     'appId',
			CONCAT([AppId],'[::]',[IntentId]) 'key',
			0                     'status',
	        0                    'totalRetries'
			FROM [Intent] (NOLOCK) WHERE [VCC] = @VCC AND [IntentId] IN (SELECT ID FROM @Intent)

		-- UTTERANCES  
					  
			 SELECT  DISTINCT
			 U.[Id] 'id',
			 U.[AppId]       'appId',
			 I.[Name]    'intent',
			 U.[IntentId] 'intentId',
			 U.[Text] 'name',
			 (SELECT [EntityName] 'entityName',[Start] 'start',[End] 'end' 
			 FROM [UtteranceEntity] (NOLOCK) WHERE [VCC] = @VCC AND [UtteranceId] IN(U.[Id]) FOR JSON AUTO) 'rawEntityLabels',
			 CONCAT(U.[AppId],'[::]',U.[IntentId],'[::]',U.[Id]) 'key',
			 CONCAT(U.[AppId],'[::]',I.[IntentId]) 'intentKey',
			 0                     'status',
			 0                    'totalRetries'
			 
			 FROM [Utterance] U (NOLOCK) 
			 INNER JOIN [Intent] I (NOLOCK)
			 ON (U.VCC = I.VCC AND U.IntentId = I.IntentId)
			 WHERE U.[VCC] = @VCC  AND U.[IntentId] IN (SELECT ID FROM @Intent)
			 
		--ENTITIES
				 SELECT 
				 [AppId] 'appId',
				 [ID] 'id',
				 [Name] 'name',
				 CONCAT([AppId],'[::]',[ID]) 'key',
				  0                     'status',
				 0                    'totalRetries'
				 FROM [dbo].[Entity] WHERE [VCC] = @VCC AND [AppId] IN (SELECT ID FROM @Intent)
	   END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_6.1.0_database.tar.gz: database/mssql/procedures/GetNluIntentUtteranceToExport.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetNluIntentUtteranceToExport]
(
	@VCC	VARCHAR(50),
	@ListMode INT = 0,
    @UseRasaApi BIT = null
)
AS
BEGIN
	SET NOCOUNT ON
    --@ListMode = 0 resumen de nlus a exportar VCC A VCC solo los que no son de sistema
    --@ListMode = 1 listado de nlus a exportar VCC A VCC solo los que no son de sistema
    --@ListMode = 2 resumen de nlus a exportar RASA A RASAAPI O VICEVERSA todos los nlu de todo el sistema
    --@ListMode = 3 listado de nlus a exportar RASA A RASAAPI O VICEVERSA todos los nlu de todo el sistema
	
	DECLARE @NLU TABLE(
	 [Name] VARCHAR(50),
	 AppId VARCHAR(50)
	)
	DECLARE @Intent TABLE (
	ID VARCHAR(50)
	)

    IF (@ListMode = 0 OR @ListMode = 1)
    BEGIN
        INSERT INTO @NLU SELECT [Name],[AppId] FROM [NLU]  (NOLOCK) WHERE [VCC] = @VCC AND [IsSystemApp] = 0 AND [Status] <> 4
        INSERT INTO @Intent SELECT [IntentId] FROM [Intent] (NOLOCK) WHERE [VCC] = @VCC AND [AppId] IN (SELECT [AppId] FROM @NLU)
    END
    ELSE
    BEGIN
        INSERT INTO @NLU SELECT  [Name],[AppId] FROM [NLU]  (NOLOCK) WHERE [VCC] = @VCC  AND [Status] <> 4 AND [CognitiveEngine] = IIF(@UseRasaApi = 1,'RASA','RASAAPI')
			
    END
   

	IF(@ListMode = 0) -- CONTAR TOTAL DE REGISTROS
	   BEGIN

        DECLARE @TotalNlu INT = 0
        DECLARE @TotalIntent INT = 0
        DECLARE @TotalUtterance INT = 0
        DECLARE @TotalEntity INT = 0
        DECLARE @NluNames VARCHAR(MAX) = NULL
                
        SELECT @TotalNlu = COUNT([Name]) FROM [NLU] (NOLOCK) WHERE [VCC] = @VCC AND [Name] IN (SELECT [Name] FROM @NLU)

        SELECT @TotalIntent = COUNT([IntentId]) FROM [Intent] (NOLOCK) WHERE [VCC] = @VCC AND [IntentId] IN (SELECT ID FROM @Intent)

        SELECT @TotalUtterance = COUNT([Id]) FROM [Utterance] (NOLOCK) WHERE [VCC] = @VCC AND [IntentId] IN (SELECT ID FROM @Intent)
                
        SELECT @TotalEntity = COUNT([ID]) FROM [dbo].[Entity] WHERE [VCC] = @VCC AND [AppId] IN (SELECT [AppId] FROM @NLU)

        SELECT @TotalNlu AS TotalNlu,@TotalIntent AS TotalIntent,@TotalUtterance AS TotalUtterance, @TotalEntity AS TotalEntity
                
        SELECT @NluNames = STUFF(( SELECT ',' + [Name] FROM [NLU]  WHERE [VCC] = @VCC AND [IsSystemApp] = 0 FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')
            
       
		SELECT 0 'InUse'
          --EXEC [GetNlusUsage] @VCC,@NluNames

	   END
	   IF (@ListMode = 1)
	   BEGIN
	   --NLUS
	       SELECT 
	       [Name]                name,
	       [Name]                originalName,
	       [Culture]             culture, 
	       [Description]         description,
	       [AppId]               appId,
	       [CognitiveEngine]     cognitiveEngine,
	       0                     'status',
	       0                    'totalRetries'
	       FROM [NLU] (NOLOCK) WHERE [VCC] = @VCC AND [Name] IN (SELECT [Name] FROM @NLU)
					--INTENTS
					   SELECT
			[Name]     'name',
			[IntentId] 'intentId',
			[AppId]     'appId',
			CONCAT([AppId],'[::]',[IntentId]) 'key',
			0                     'status',
	        0                    'totalRetries'
			FROM [Intent] (NOLOCK) WHERE [VCC] = @VCC AND [IntentId] IN (SELECT ID FROM @Intent)
					--UTTERANCES  
					  
			 SELECT DISTINCT
			 U.[Id] 'id',
			 U.[AppId]       'appId',
			 I.[Name]    'intent',
			 U.[IntentId] 'intentId',
			 U.[Text] 'name',
			 (SELECT [EntityName] 'entityName',[Start] 'start',[End] 'end' 
			 FROM [UtteranceEntity] (NOLOCK) WHERE [VCC] = @VCC AND [UtteranceId] IN(U.[Id]) FOR JSON AUTO) 'rawEntityLabels',
			 CONCAT(U.[AppId],'[::]',U.[IntentId],'[::]',U.[Id]) 'key',
			 CONCAT(U.[AppId],'[::]',I.[IntentId]) 'intentKey',
			 0                     'status',
			 0                    'totalRetries'
			 
			 FROM [Utterance] U (NOLOCK) 
			 JOIN [Intent] I (NOLOCK)
			 ON (U.VCC = I.VCC AND U.IntentId = I.IntentId)
			 WHERE U.[VCC] = @VCC AND U.[IntentId] IN (SELECT ID FROM @Intent)
			 
			  --ENTITIES
			 SELECT 
			 [AppId] 'appId',
			 [ID] 'id',
			 [Name] 'name',
			 CONCAT([AppId],'[::]',[ID]) 'key',
			  0                     'status',
			 0                    'totalRetries'
			 FROM [dbo].[Entity] WHERE [VCC] = @VCC AND [AppId] IN (SELECT [AppId] FROM @NLU)
	   END
       IF (@ListMode = 2)
       BEGIN
        IF(@VCC ='ALL') --LISTAR RESUMEN PARA TODOS LOS VCCS RASA O RASAAPI
        BEGIN
                WITH ALL_NLUS AS (
                    SELECT   N.[VCC],N.[CognitiveEngine],
                    (SELECT COUNT(1) FROM [dbo].[Nlu] WHERE VCC = N.[VCC] AND appid = N.appid) 'totalNlu',
					0 'totalIntent',
                    0 'totalUtterance',
                    0 'totalEntity'


                    FROM [dbo].[Nlu] N WHERE 
                    N.[CognitiveEngine] = IIF(@UseRasaApi = 1,'RASA','RASAAPI')
                )

                SELECT TOP 1 
                    AN.[VCC]                'vcc',
                    AN.[CognitiveEngine]    'cognitiveEngine',
                    SUM(TotalNlu)               'totalNlu',
                    SUM(TotalIntent)            'totalIntent',
                    SUM(TotalUtterance)         'totalUtterance',
                    SUM(TotalEntity)            'totalEntity'
                FROM ALL_NLUS AN
                    INNER JOIN [dbo].[VCC] V ON V.[VCC] = AN.[VCC]
                WHERE V.[IsMigrating] = 0 
                    GROUP BY AN.[VCC],  AN.[CognitiveEngine]	
            		
        END
        SELECT 0 'InUse'
      END
     IF (@ListMode = 3)
	   BEGIN
	   --NLUS
	       SELECT 
	       [Name]                name,
	       [Name]                originalName,
	       [Culture]             culture, 
	       [Description]         description,
	       [AppId]               appId,
	       [CognitiveEngine]     cognitiveEngine,
	       0                     'status',
	       0                    'totalRetries'
	       FROM [NLU] (NOLOCK) WHERE [VCC] = @VCC AND [Name] IN (SELECT [Name] FROM @NLU)
		 --INTENTS
			SELECT
			[Name]     'name',
			[IntentId] 'intentId',
			[AppId]     'appId',
			CONCAT([AppId],'[::]',[IntentId]) 'key',
			0                     'status',
	        0                    'totalRetries'
			FROM [Intent] (NOLOCK) WHERE [VCC] = @VCC AND [IntentId] IN (SELECT ID FROM @Intent)

		-- UTTERANCES  
					  
			 SELECT  DISTINCT
			 U.[Id] 'id',
			 U.[AppId]       'appId',
			 I.[Name]    'intent',
			 U.[IntentId] 'intentId',
			 U.[Text] 'name',
			 (SELECT [EntityName] 'entityName',[Start] 'start',[End] 'end' 
			 FROM [UtteranceEntity] (NOLOCK) WHERE [VCC] = @VCC AND [UtteranceId] IN(U.[Id]) FOR JSON AUTO) 'rawEntityLabels',
			 CONCAT(U.[AppId],'[::]',U.[IntentId],'[::]',U.[Id]) 'key',
			 CONCAT(U.[AppId],'[::]',I.[IntentId]) 'intentKey',
			 0                     'status',
			 0                    'totalRetries'
			 
			 FROM [Utterance] U (NOLOCK) 
			 INNER JOIN [Intent] I (NOLOCK)
			 ON (U.VCC = I.VCC AND U.IntentId = I.IntentId)
			 WHERE U.[VCC] = @VCC  AND U.[IntentId] IN (SELECT ID FROM @Intent)
			 
		--ENTITIES
				 SELECT 
				 [AppId] 'appId',
				 [ID] 'id',
				 [Name] 'name',
				 CONCAT([AppId],'[::]',[ID]) 'key',
				  0                     'status',
				 0                    'totalRetries'
				 FROM [dbo].[Entity] WHERE [VCC] = @VCC AND [AppId] IN (SELECT ID FROM @Intent)
	   END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
